<?php
if (!defined('ABSPATH'))
    die('No direct access allowed');

final class CWPF_EXT_BY_FEATURED extends CWPF_EXT {

    public $type = 'by_html_type';
    public $html_type = 'by_featured'; //your custom key here
    public $index = 'featured';
    public $html_type_dynamic_recount_behavior = 'none';

    public function __construct()
    {
        parent::__construct();
        $this->init();
    }

    public function get_ext_path()
    {
        return plugin_dir_path(__FILE__);
    }
    public function get_ext_override_path()
    {
        return get_stylesheet_directory(). DIRECTORY_SEPARATOR ."cwpf". DIRECTORY_SEPARATOR ."ext". DIRECTORY_SEPARATOR .$this->html_type. DIRECTORY_SEPARATOR;
    }
    
    public function get_ext_link()
    {
        return plugin_dir_url(__FILE__);
    }

    public function cwpf_add_items_keys($keys)
    {
        $keys[] = $this->html_type;
        return $keys;
    }

    public function init()
    {
        add_filter('cwpf_add_items_keys', array($this, 'cwpf_add_items_keys'));
        add_action('cwpf_print_html_type_options_' . $this->html_type, array($this, 'cwpf_print_html_type_options'), 10, 1);
        add_action('cwpf_print_html_type_' . $this->html_type, array($this, 'print_html_type'), 10, 1);
        //add_action('parse_query', array($this, "parse_query"), 9999);
        add_action( 'woocommerce_product_query',array($this,'parse_query'));
        add_action('cwpf_get_tax_query', array($this, "cwpf_get_tax_query"), 9999);
        add_action('wp_head', array($this, 'wp_head'), 999);

        self::$includes['js']['cwpf_' . $this->html_type . '_html_items'] = $this->get_ext_link() . 'js/' . $this->html_type . '.js';
        self::$includes['css']['cwpf_' . $this->html_type . '_html_items'] = $this->get_ext_link() . 'css/' . $this->html_type . '.css';
        self::$includes['js_init_functions'][$this->html_type] = 'cwpf_init_featured';
    }

    public function wp_head()
    {
        global $CWPF;
        ?>      
        <script type="text/javascript">
            if (typeof cwpf_lang_custom == 'undefined') {
                var cwpf_lang_custom = {};/*!!important*/
            }
            cwpf_lang_custom.<?php echo $this->index ?> = "<?php _e('Featured product', 'cwpfilter') ?>";
        </script>
        <?php
    }

    //settings page hook
    public function cwpf_print_html_type_options()
    {
        global $CWPF;
        echo $CWPF->render_html($this->get_ext_path() . 'views' . DIRECTORY_SEPARATOR . 'options.php', array(
            'key' => $this->html_type,
            "cwpf_settings" => get_option('cwpf_settings', array())
                )
        );
    }

    public function parse_query($wp_query){
            if(!isset($wp_query->query['post_type']) OR $wp_query->query['post_type']!='product'){
                //return $wp_query;
            }

            if (!empty($wp_query->tax_query) AND isset($wp_query->tax_query->queries)) {
              global $CWPF;
              $request = $CWPF->get_request_data();
              if(isset($request["product_visibility"]) AND $request["product_visibility"]=='featured'){
                $tax_query = $wp_query->tax_query->queries;
                $tax_query=$this->add_to_tax_query($tax_query);
                $wp_query->set('tax_query', $tax_query);
              }   
            }  
        
    }
    public function add_to_tax_query($tax_query){
        $tax_query[]=array(
                            'taxonomy' => 'product_visibility',
                            'field'    => 'name',
                            'terms'    => 'featured',
                          );
        return $tax_query;  
    }
    public function cwpf_get_tax_query($tax_query){
        
        global $CWPF;
        $request = $CWPF->get_request_data();
        if(isset($request["product_visibility"]) AND $request["product_visibility"]=='featured'){
            $tax_query=$this->add_to_tax_query($tax_query);       
        }     
        return $tax_query;
    }

}

CWPF_EXT::$includes['html_type_objects']['by_featured'] = new CWPF_EXT_BY_FEATURED();
