<?php
if (!defined('ABSPATH'))
    die('No direct access allowed');

final class CWPF_EXT_BY_TEXT extends CWPF_EXT {

    public $type = 'by_html_type';
    public $html_type = 'by_text'; //your custom key here
    public $index = 'cwpf_text';
    public $html_type_dynamic_recount_behavior = 'none';

    public function __construct() {
        parent::__construct();
        $this->init();
    }

    public function get_ext_path() {
        return plugin_dir_path(__FILE__);
    }

    public function get_ext_override_path() {
        return get_stylesheet_directory() . DIRECTORY_SEPARATOR . "cwpf" . DIRECTORY_SEPARATOR . "ext" . DIRECTORY_SEPARATOR . $this->html_type . DIRECTORY_SEPARATOR;
    }

    public function get_ext_link() {
        return plugin_dir_url(__FILE__);
    }

    public function cwpf_add_items_keys($keys) {
        $keys[] = $this->html_type;
        return $keys;
    }

    public function init() {
        add_filter('cwpf_add_items_keys', array($this, 'cwpf_add_items_keys'));
        add_filter('cwpf_get_request_data', array($this, 'cwpf_get_request_data'));
        add_action('cwpf_print_html_type_options_' . $this->html_type, array($this, 'cwpf_print_html_type_options'), 10, 1);
        add_action('cwpf_print_html_type_' . $this->html_type, array($this, 'print_html_type'), 10, 1);
        add_action('wp_head', array($this, 'wp_head'), 999);

        add_action('wp_ajax_cwpf_text_autocomplete', array($this, 'cwpf_text_autocomplete'));
        add_action('wp_ajax_nopriv_cwpf_text_autocomplete', array($this, 'cwpf_text_autocomplete'));

        self::$includes['js']['cwpf_' . $this->html_type . '_html_items'] = $this->get_ext_link() . 'js/' . $this->html_type . '.js';
        self::$includes['css']['cwpf_' . $this->html_type . '_html_items'] = $this->get_ext_link() . 'css/' . $this->html_type . '.css';
        self::$includes['js_init_functions'][$this->html_type] = 'cwpf_init_text'; //we have no init function in this case
        //***
        add_shortcode('cwpf_text_filter', array($this, 'cwpf_text_filter'));
    }

    public function cwpf_get_request_data($request) {
        if (isset($request['s'])) {
            $request['cwpf_text'] = $request['s'];
            //unset($request['s']);
        }

        return $request;
    }

    public function wp_head() {
        global $CWPF;
        //***
        //var_dump($CWPF->settings['by_text']);
        if (isset($CWPF->settings['by_text']['autocomplete']) AND $CWPF->settings['by_text']['autocomplete']) {
            wp_enqueue_script('easy-autocomplete', CWPF_JS_LINK . 'easy-autocomplete/jquery.easy-autocomplete.min.js', array('jquery'), CWPF_VERSION);
            wp_enqueue_style('easy-autocomplete', CWPF_JS_LINK . 'easy-autocomplete/easy-autocomplete.min.css', array(), CWPF_VERSION);
            wp_enqueue_style('easy-autocomplete-theme', CWPF_JS_LINK . 'easy-autocomplete/easy-autocomplete.themes.min.css', array(), CWPF_VERSION);
        }
        ?>
        <style type="text/css">
        <?php
        if (isset($CWPF->settings['by_text']['image'])) {
            if (!empty($CWPF->settings['by_text']['image'])) {
                ?>
                    .cwpf_text_search_container .cwpf_text_search_go{
                        background: url(<?php echo $CWPF->settings['by_text']['image'] ?>) !important;
                    }
                <?php
            }
        }
        ?>
        </style>
        <script type="text/javascript">
            if (typeof cwpf_lang_custom == 'undefined') {
                var cwpf_lang_custom = {};/*!!important*/
            }
            cwpf_lang_custom.<?php echo $this->index ?> = "<?php _e('By text', 'cwpfilter') ?>";

            var cwpf_text_autocomplete = 0;
            var cwpf_text_autocomplete_items = 10;
        <?php if (isset($CWPF->settings['by_text']['autocomplete'])): ?>
                cwpf_text_autocomplete =<?php echo (int) $CWPF->settings['by_text']['autocomplete']; ?>;
                cwpf_text_autocomplete_items =<?php echo apply_filters('cwpf_text_autocomplete_items', 10) ?>;
        <?php endif; ?>

            var cwpf_post_links_in_autocomplete = 0;
        <?php if (isset($CWPF->settings['by_text']['post_links_in_autocomplete'])): ?>
                cwpf_post_links_in_autocomplete =<?php echo (int) $CWPF->settings['by_text']['post_links_in_autocomplete']; ?>;
        <?php endif; ?>

            var how_to_open_links = 0;
        <?php if (isset($CWPF->settings['by_text']['how_to_open_links'])): ?>
                how_to_open_links =<?php echo (int) $CWPF->settings['by_text']['how_to_open_links']; ?>;
        <?php endif; ?>

        </script>
        <?php
    }

    //shortcode
    public function cwpf_text_filter($args = array()) {
        global $CWPF;
        if (!is_array($args)) {
            $args = array();
        }
        $args['loader_img'] = $this->get_ext_link() . 'img/loader.gif';

        if (file_exists($this->get_ext_override_path() . 'views' . DIRECTORY_SEPARATOR . 'shortcodes' . DIRECTORY_SEPARATOR . 'cwpf_text_filter.php')) {
            return $CWPF->render_html($this->get_ext_override_path() . 'views' . DIRECTORY_SEPARATOR . 'shortcodes' . DIRECTORY_SEPARATOR . 'cwpf_text_filter.php', $args);
        }

        return $CWPF->render_html($this->get_ext_path() . 'views' . DIRECTORY_SEPARATOR . 'shortcodes' . DIRECTORY_SEPARATOR . 'cwpf_text_filter.php', $args);
    }

    //settings page hook
    public function cwpf_print_html_type_options() {
        global $CWPF;
        echo $CWPF->render_html($this->get_ext_path() . 'views' . DIRECTORY_SEPARATOR . 'options.php', array(
            'key' => $this->html_type,
            "cwpf_settings" => get_option('cwpf_settings', array())
                )
        );
    }

    public function assemble_query_params(&$meta_query, $wp_query = NULL) {
        add_filter('posts_where', array($this, 'cwpf_post_text_filter'), 9999, 2); //for searching by text
        return $meta_query;
    }

    public function cwpf_post_text_filter($where = '', $query = null) {
        global $wp_query;
        global $CWPF;
        $request = $CWPF->get_request_data();
        if (!$wp_query->is_main_query()) {
            //return $where;
        }
        //***

        if (!defined('DOING_AJAX')) {
            if (!isset($query->query_vars['post_type'])) {
                return $where;
            }
            if(is_array($query->query_vars['post_type'])){
                if(!in_array("product", $query->query_vars['post_type'])) return $where;
            }else{
                if($query->query_vars['post_type'] != 'product')return $where;
            }
        }
        if (isset($request['s'])) {
            //uncomment it for cyrillic text search - old, do not touch
            //return $where;
        }

        //***
        if (!isset($request['cwpf_text']) OR ! $request['cwpf_text']) {
            return $where;
        }

        if (defined('DOING_AJAX')) {
            $conditions = (isset($wp_query->query_vars['post_type']) AND $wp_query->query_vars['post_type'] == 'product') OR isset($_REQUEST['cwpf_products_doing']);
        } else {
            $conditions = isset($_REQUEST['cwpf_products_doing']);
        }
        //***
        //if ($conditions)
        {
            if ($CWPF->is_isset_in_request_data('cwpf_text')) {

                $cwpf_text = wp_specialchars_decode(trim(urldecode($request['cwpf_text'])));
                $cwpf_text = trim(CWPF_HELPER::strtolower($cwpf_text));
                $cwpf_text = preg_replace('/\s+/', ' ', $cwpf_text);

                if (!apply_filters('cwpf_text_search_like_option', false)) {
                    $cwpf_text = preg_quote($cwpf_text, '&');
                    $cwpf_text = str_replace(' ', '?(.*)', $cwpf_text);
                    //$cwpf_text = str_replace(' ', '?(.*)', $cwpf_text);
                    $cwpf_text = str_replace("\&#039;", "\'", $cwpf_text);
                    $cwpf_text = str_replace("\&quot;", "\"", $cwpf_text);
                    $cwpf_text = str_replace("\(", "\\\(", $cwpf_text);
                    $cwpf_text = str_replace("\)", "\\\)", $cwpf_text);
                    //http://dev.mysql.com/doc/refman/5.7/en/regexp.html
                    $search_by_full_word = false;

                    if (isset($CWPF->settings['by_text']['search_by_full_word'])) {
                        $search_by_full_word = (int) $CWPF->settings['by_text']['search_by_full_word'];
                    }

                    if ($search_by_full_word) {
                        $cwpf_text = '[[:<:]]' . $cwpf_text . '[[:>:]]';
                    }

                    //***

                    $behavior = 'title';
                    if (isset($CWPF->settings['by_text']['behavior'])) {
                        $behavior = $CWPF->settings['by_text']['behavior'];
                    }

                    if (isset($_REQUEST['auto_search_by_behavior']) AND ! empty($_REQUEST['auto_search_by_behavior'])) {
                        $behavior = $_REQUEST['auto_search_by_behavior'];
                    }

                    $text_where = "";
                    //***
                    switch ($behavior) {
                        case 'content':
                            $text_where .= " LOWER(post_content) REGEXP '{$cwpf_text}'";
                            break;

                        case 'title_or_content':
                            $text_where .= " ( LOWER(post_title) REGEXP '{$cwpf_text}' OR LOWER(post_content) REGEXP '{$cwpf_text}')";
                            break;

                        case 'title_and_content':
                            $text_where .= " ( LOWER(post_title) REGEXP '{$cwpf_text}' AND LOWER(post_content) REGEXP '{$cwpf_text}')";
                            break;

                        case 'excerpt':
                            $text_where .= " LOWER(post_excerpt) REGEXP '{$cwpf_text}'";
                            break;

                        case 'content_or_excerpt':
                            $text_where .= " ( LOWER(post_excerpt) REGEXP '{$cwpf_text}' OR LOWER(post_content) REGEXP '{$cwpf_text}')";
                            break;

                        case 'title_or_content_or_excerpt':
                            $text_where .= "  (( LOWER(post_title) REGEXP '{$cwpf_text}') OR ( LOWER(post_excerpt) REGEXP '{$cwpf_text}') OR ( LOWER(post_content) REGEXP '{$cwpf_text}'))";
                            break;

                        default:
                            //only by title
                            $text_where .= "  LOWER(post_title) REGEXP '{$cwpf_text}'";
                            break;
                    }
                } else {
                    $cwpf_text = str_replace("\&#039;", "\'", $cwpf_text);
                    $cwpf_text = str_replace("\&quot;", "\"", $cwpf_text);
                    $cwpf_text = str_replace("\(", "\\\(", $cwpf_text);
                    $cwpf_text = str_replace("\)", "\\\)", $cwpf_text);

                    $search_by_full_word = false;

                    if (isset($CWPF->settings['by_text']['search_by_full_word'])) {
                        $search_by_full_word = (int) $CWPF->settings['by_text']['search_by_full_word'];
                    }
                    $cwpf_text_array = explode(" ", $cwpf_text);
                    $text_where = "";
                    $text_array = array();
                    foreach ($cwpf_text_array as $text) {

                        if (!$search_by_full_word) {
                            $text = '%' . $text . '%';
                        }

                        $behavior = 'title';
                        if (isset($CWPF->settings['by_text']['behavior'])) {
                            $behavior = $CWPF->settings['by_text']['behavior'];
                        }

                        if (isset($_REQUEST['auto_search_by_behavior']) AND ! empty($_REQUEST['auto_search_by_behavior'])) {
                            $behavior = $_REQUEST['auto_search_by_behavior'];
                        }


                        //***
                        switch ($behavior) {
                            case 'content':
                                $text_array[] = "( LOWER(post_content) LIKE '{$text}')";
                                break;

                            case 'title_or_content':
                                $text_array[] = " ( LOWER(post_title) LIKE '{$text}' OR LOWER(post_content) LIKE '{$text}')";
                                break;

                            case 'title_and_content':
                                $text_array[] = " ( LOWER(post_title) LIKE '{$text}' AND LOWER(post_content) LIKE '{$text}')";
                                break;

                            case 'excerpt':
                                $text_array[] = " LOWER(post_excerpt) LIKE '{$text}'";
                                break;

                            case 'content_or_excerpt':
                                $text_array[] = " ( LOWER(post_excerpt) LIKE '{$text}' OR LOWER(post_content) LIKE '{$text}')";
                                break;

                            case 'title_or_content_or_excerpt':
                                $text_array[] .= "  (( LOWER(post_title) LIKE '{$text}') OR ( LOWER(post_excerpt) LIKE '{$text}') OR ( LOWER(post_content) LIKE '{$cwpf_text}'))";
                                break;

                            default:
                                //only by title
                                $text_array[] = " ( LOWER(post_title) LIKE '{$text}' ) ";
                                break;
                        }
                    }
                    $text_where = implode(" AND ", $text_array);
                }
                global $wpdb;

                //_variation_description
                $var_desc_where = "";
                if (isset($CWPF->settings['by_text']['search_desc_variant']) AND $CWPF->settings['by_text']['search_desc_variant']) {
                    if (!in_array($behavior, array('excerpt', 'content', 'title'))) {
                        $condtion_string = "";
                        if (!empty($cwpf_text)) {

                            if (!apply_filters('cwpf_text_search_like_option', false)) {
                                $condtion_string .= " LOWER(postmeta.meta_value) REGEXP '{$cwpf_text}'";
                            } else {
                                $condtion_string .= " postmeta.meta_value LIKE '%$cwpf_text%'";
                            }
                        }

                        //***

                        $product_variations = $wpdb->get_results("
                        SELECT posts.ID
                        FROM $wpdb->posts AS posts
                        LEFT JOIN $wpdb->postmeta AS postmeta ON ( posts.ID = postmeta.post_id )
                        WHERE posts.post_type IN ('product_variation')
                        AND postmeta.meta_key = '_variation_description'
                        AND ($condtion_string)", ARRAY_N);
                        //+++
                        $product_variations_ids = array();
                        if (!empty($product_variations)) {
                            foreach ($product_variations as $v) {
                                $product_variations_ids[] = $v[0];
                            }

                            //+++
                            $product_variations_ids_string = implode(',', $product_variations_ids);
                            //die($product_variations_ids_string);
                            $products = $wpdb->get_results("
                            SELECT posts.post_parent
                            FROM $wpdb->posts AS posts
                            WHERE posts.ID IN ($product_variations_ids_string) AND posts.post_parent > 0", ARRAY_N);
                            //+++
                            $product_ids = array();
                            if (!empty($products)) {
                                foreach ($products as $v) {
                                    $product_ids[] = $v[0];
                                }
                            }

                            $product_ids = implode(',', array_merge($product_ids, $product_variations_ids));
                            $var_desc_where .= " $wpdb->posts.ID IN($product_ids)";
                            //$where_sku = " AND $wpdb->posts.ID IN($product_ids)";
                            //die($where);
                        }
                        if ($var_desc_where AND ! empty($var_desc_where)) {
                            $condition = " OR ";
                            if ($behavior = 'title_and_content') {
                                $condition = " OR ";
                            }
                            $var_desc_where = $condition . $var_desc_where;
                        }
                    }
                }


                //by SKU  *******************
                $sku_where = "";
                if ($CWPF->settings['by_text']['sku_compatibility']) {
                    //$cwpf_text = trim(urldecode($request['cwpf_sku']));
                    $cwpf_sku_request = explode(',', $request['cwpf_text']);
                    $cwpf_sku_request = array_map('urldecode', $cwpf_sku_request);
                    $cwpf_sku_request = array_map('trim', $cwpf_sku_request);
                    //***
                    if (!isset($CWPF->settings['by_sku']['logic']) OR empty($CWPF->settings['by_sku']['logic'])) {
                        $CWPF->settings['by_sku']['logic'] = 'LIKE';
                    }

                    $condtion_string = "";
                    if (!empty($cwpf_sku_request)) {
                        foreach ($cwpf_sku_request as $k => $sku) {
                            if ($k > 0) {
                                $condtion_string .= " OR ";
                            }
                            if ($CWPF->settings['by_sku']['logic'] == '=') {
                                $condtion_string .= "postmeta.meta_value {$CWPF->settings['by_sku']['logic']} '$sku'";
                            } else {
                                $condtion_string .= "postmeta.meta_value {$CWPF->settings['by_sku']['logic']} '%$sku%'";
                            }
                        }
                    }

                    //***

                    $product_variations = $wpdb->get_results("
                    SELECT posts.ID
                    FROM $wpdb->posts AS posts
                    LEFT JOIN $wpdb->postmeta AS postmeta ON ( posts.ID = postmeta.post_id )
                    WHERE posts.post_type IN ('product_variation','product')
                    AND postmeta.meta_key = '_sku'
                    AND ($condtion_string)", ARRAY_N);
                    //+++
                    $product_variations_ids = array();
                    if (!empty($product_variations)) {
                        foreach ($product_variations as $v) {
                            $product_variations_ids[] = $v[0];
                        }

                        //+++
                        $product_variations_ids_string = implode(',', $product_variations_ids);
                        //die($product_variations_ids_string);
                        $products = $wpdb->get_results("
                        SELECT posts.post_parent
                        FROM $wpdb->posts AS posts
                        WHERE posts.ID IN ($product_variations_ids_string) AND posts.post_parent > 0", ARRAY_N);
                        //+++
                        $product_ids = array();
                        if (!empty($products)) {
                            foreach ($products as $v) {
                                $product_ids[] = $v[0];
                            }
                        }
                        $product_ids = implode(',', array_merge($product_ids, $product_variations_ids));
                        $sku_where .= " $wpdb->posts.ID IN($product_ids)";
                        $where_sku = " AND $wpdb->posts.ID IN($product_ids)";
                        //die($where);
                    }
                    if ($sku_where AND ! empty($sku_where)) {
                        $sku_where = " OR " . $sku_where;
                    }
                }
                //by SKU  *******************
                $where .= " AND ( " . $text_where . $var_desc_where . $sku_where . " )   ";
            }
        }
        //***

        return $where;
    }

    //ajax
    public function cwpf_text_autocomplete() {
        $results = array();
        $args = array(
            'nopaging' => true,
            //'fields' => 'ids',
            'post_type' => 'product',
            'post_status' => array('publish'),
            'orderby' => 'title',
            'order' => 'ASC',
            'max_num_pages' => intval($_REQUEST['auto_res_count']) > 0 ? intval($_REQUEST['auto_res_count']) : apply_filters('cwpf_text_autocomplete_items', 10)
        );

        if (class_exists('SitePress')) {
            $args['lang'] = ICL_LANGUAGE_CODE;
        }

        //***

        $_GET['cwpf_text'] = $_REQUEST['phrase'];
        if (!empty($_REQUEST['auto_search_by'])) {
            $_REQUEST['auto_search_by_behavior'] = $_REQUEST['auto_search_by'];
        }
        add_filter('posts_where', array($this, 'cwpf_post_text_filter'), 10);
        $query = new WP_Query($args);
        //+++
        //http://easyautocomplete.com/guide
        if ($query->have_posts()) {
            include_once CWPF_LIB_PATH . 'aq_resizer.php';
            foreach ($query->posts as $p) {
                $data = array(
                    //"name" => $p->post_title . ' (#' . $p->ID . ')',
                    "name" => $p->post_title,
                    "type" => "product"
                );
                if (has_post_thumbnail($p->ID)) {
                    $img_src = wp_get_attachment_image_src(get_post_thumbnail_id($p->ID), 'single-post-thumbnail');
                    $data['icon'] = cwpf_aq_resize($img_src[0], 100, 100, true);
                } else {
                    $data['icon'] = CWPF_IMG_LINK . 'not-found.jpg';
                }
                $data['link'] = get_post_permalink($p->ID);
                $results[] = $data;
            }
        } else {
            $results[] = array(
                "name" => __("Products not found!", 'cwpfilter'),
                "type" => "",
                "link" => "#",
                "icon" => CWPF_IMG_LINK . 'not-found.jpg'
            );
        }

        die(json_encode($results));
    }

}

CWPF_EXT::$includes['html_type_objects']['by_text'] = new CWPF_EXT_BY_TEXT();
