<?php
if (!defined('ABSPATH'))
    die('No direct access allowed');

final class CWPF_EXT_IMAGE extends CWPF_EXT {

    public $type = 'html_type';
    public $html_type = 'image'; //your custom key here
    public $html_type_dynamic_recount_behavior = 'multi';

    public function __construct() {
        parent::__construct();
        $this->init();
    }

    public function get_ext_path() {
        return plugin_dir_path(__FILE__);
    }

    public function get_ext_override_path() {
        return get_stylesheet_directory() . DIRECTORY_SEPARATOR . "cwpf" . DIRECTORY_SEPARATOR . "ext" . DIRECTORY_SEPARATOR . $this->html_type . DIRECTORY_SEPARATOR;
    }

    public function get_ext_link() {
        return plugin_dir_url(__FILE__);
    }

    public function init() {
        add_filter('cwpf_add_html_types', array($this, 'cwpf_add_html_types'));
        add_action('wp_head', array($this, 'wp_head'), 999);
        add_action('woocommerce_settings_tabs_cwpf', array($this, 'woocommerce_settings_tabs_cwpf'), 51);
        add_action('cwpf_print_tax_additional_options_image', array($this, 'print_additional_options'), 10, 1);
        add_action('cwpf_print_design_additional_options', array($this, 'cwpf_print_design_additional_options'), 10, 1);
        self::$includes['js']['cwpf_' . $this->html_type . '_html_items'] = $this->get_ext_link() . 'js/html_types/' . $this->html_type . '.js';
        self::$includes['css']['cwpf_' . $this->html_type . '_html_items'] = $this->get_ext_link() . 'css/html_types/' . $this->html_type . '.css';
        self::$includes['js_init_functions'][$this->html_type] = 'cwpf_init_image';

        add_action('admin_head', array($this, 'admin_head'), 50);

        /*
          $this->taxonomy_type_additional_options = array(
          'checked_image' => array(
          'title' => __('Image for checked image type checkbox', 'cwpfilter'),
          'tip' => __('Image for image checkboxes when its checked. Better use png. Size is: 25x25 px.', 'cwpfilter'),
          'type' => 'image'
          )
          );
         */
        $this->taxonomy_type_additional_options = array(
            'show_title' => array(
                'title' => __('Show image title', 'cwpfilter'),
                'tip' => __('Show image title below picture', 'cwpfilter'),
                'type' => 'select',
                'options' => array(
                    0 => __('No', 'cwpfilter'),
                    1 => __('Yes', 'cwpfilter'),
                )
            ),
            'as_radio' => array(
                'title' => __('Behavior as radio button', 'cwpfilter'),
                'tip' => __('Use image as radio button', 'cwpfilter'),
                'type' => 'select',
                'options' => array(
                    0 => __('No', 'cwpfilter'),
                    1 => __('Yes', 'cwpfilter'),
                )
            ),
        );
    }

    public function admin_head() {
        if (isset($_GET['tab']) AND $_GET['tab'] == 'cwpf') {
            wp_enqueue_style('cwpf_image', $this->get_ext_link() . 'css/admin.css', array(), CWPF_VERSION);
            wp_enqueue_script('cwpf_image', $this->get_ext_link() . 'js/html_types/plugin_options.js', array('jquery'), CWPF_VERSION);
        }
    }

    public function cwpf_add_html_types($types) {
        $types[$this->html_type] = __('Image', 'cwpfilter');
        return $types;
    }

    public function woocommerce_settings_tabs_cwpf() {
        //wp_enqueue_style('wp-image-picker');
        //wp_enqueue_script('wp-image-picker');
    }

    public function wp_head() {
        
    }

    public function print_additional_options($key) {
        global $CWPF;
        $cwpf_settings = $CWPF->settings;
        $terms = CWPF_HELPER::get_terms($key, 0, 0, 0, 0);
        if (!empty($terms)) {
            ?>
            <br /><a href="javascript:void(0);" class="button cwpf_toggle_images"><?php _e('toggle image terms', 'cwpfilter') ?></a><br />
            <ul class="cwpf_image_list">
                <?php
                foreach ($terms as $t) {
                    $term_key = 'images_term_' . $t['term_id'];
                    $image = '';
                    if (isset($cwpf_settings[$term_key]['image_url'])) {
                        $image = $cwpf_settings[$term_key]['image_url'];
                    }

                    if (!isset($cwpf_settings[$term_key]['image_styles'])) {
                        $cwpf_settings[$term_key]['image_styles'] = '
width: 50px;
height:50px;
background-size: 100% 100%;
background-clip: content-box;
color: #292f38;
font-size: 0;
text-align: center;
cursor: pointer;
-webkit-border-radius: 4px;
border-radius: 4px;
-webkit-transition: border-color .35s ease;
transition: border-color .35s ease;';
                    }
                    ?>
                    <li>
                        <table>
                            <tr>

                                <td>
                                    <input type="text" name="cwpf_settings[<?php echo $term_key ?>][image_url]" value="<?php echo $image ?>" placeholder="<?php _e('set link to the image', 'cwpfilter') ?>" class="text" style="width: 600px;" />
                                    <a href="#" class="cwpf-button cwpf_select_image"><?php _e('Select Image', 'cwpfilter') ?></a>
                                </td>
                                <td>
                                    <input type="button" value="&#43;" data-key="<?php echo $term_key ?>" data-name="<?php printf(__('Image settings for term %s', 'cwpfilter'), $t['name']) ?>" class="cwpf-button js_cwpf_options js_cwpf_options_image icon-book">
                                    <input type="hidden" name="cwpf_settings[<?php echo $term_key ?>][image_styles]" value="<?php echo $cwpf_settings[$term_key]['image_styles'] ?>" />

                                    <div id="cwpf-modal-content-<?php echo $term_key ?>" style="display: none;">

                                        <div class="cwpf-form-element-container">

                                            <div class="cwpf-name-description" style="width: 20%;">
                                                <strong><?php _e('Image styles', 'cwpfilter') ?></strong>
                                                <span><?php _e('This option should be set', 'cwpfilter') ?></span>
                                            </div>                                       


                                            <div class="cwpf-form-element" style="width: 80%;">
                                                <textarea class="cwpf_popup_option" data-option="image_styles"></textarea><br />
                                                <b><?php _e('Example', 'cwpfilter') ?>:</b><br />
                                                <code>width: 50px;<br />
                                                    height:50px;<br />
                                                    background-size: 100% 100%;<br />
                                                    background-clip: content-box;<br />
                                                    color: #292f38;<br />
                                                    font-size: 0;<br />
                                                    text-align: center;<br />
                                                    cursor: pointer;<br />
                                                    -webkit-border-radius: 4px;<br />
                                                    border-radius: 4px;<br />
                                                    -webkit-transition: border-color .35s ease;<br />
                                                    transition: border-color .35s ease;<br />
                                                </code>
                                            </div>

                                        </div>



                                    </div>
                                </td>
                                <td valign="top" style="padding: 4px 0 0 0;">
                                    <p class="description"> [ <?php echo CWPF_HELPER::strtolower($t['slug']); ?> ]</p>
                                </td>
                            </tr>
                        </table>
                    </li>
                    <?php
                }
                echo '</ul>';
            }
        }

        public function cwpf_print_design_additional_options() {
            global $CWPF;
            $cwpf_settings = $CWPF->settings;

            if (!isset($cwpf_settings['checked_image'])) {
                $cwpf_settings['checked_image'] = '';
            }
            ?>

            <!--<div class="cwpf-control-section">

                            <<?php echo apply_filters('cwpf_title_tag', 'h4'); ?>><?php _e('Image for checked image type checkbox', 'cwpfilter') ?></<?php echo apply_filters('cwpf_title_tag', 'h4'); ?>>

                <div class="cwpf-control-container">
                    <div class="cwpf-control cwpf-upload-style-wrap">
                                            <input type="text" name="cwpf_settings[checked_image]" value="<?php //echo $cwpf_settings['checked_image']              ?>" />
                                            <a href="#" class="cwpf-button cwpf_select_image"><?php _e('Select Image', 'cwpfilter') ?></a>
                    </div>
                    <div class="cwpf-description">
                                            <p class="description"><?php _e('Image for image checkboxes when its checked. Better use png. Size is: 25x25 px.', 'cwpfilter') ?></p>
                    </div>
                </div>

            </div> -->

            <?php
        }

    }

    CWPF_EXT::$includes['taxonomy_type_objects']['image'] = new CWPF_EXT_IMAGE();
    